# anarchy_bot

telegram bot that can promote any user to admin

## install

```bash
pip install -U anarchy_bot
```

## run

```bash
python -m anarchy_bot
```

## translate to your language

- fork repo
- go to [anarchy_bot/lang](https://github.com/gmankab/anarchy_bot/tree/main/anarchy_bot/lang)
- duplicate `en.yml` file
- rename it to something like `ru.yml`
- edit file
- make pull request
- bot automatically decects language set in user's telegram client, and will search the dir for file with translation

